==> handyman_updated_files11.5.3.zip: handyman_updated_files11.5.3/resources/lang/fr/landingpage.php <==
<?php

return [

    'home' => 'Accueil',
    'categories' => 'Catégories',
    'services' => 'Services',
    'blogs' => 'Blogs',
    'providers' => 'Fournisseurs',
    'bookings' => 'Réservations',
    'post_jobs' => 'Publier un emploi',
    'previous' => 'Précédent',
    'next' => 'Suivant',
    'post' => 'Post',
    'no_previous_post' => 'Aucun message précédent',
    'no_next_post' => 'Aucun message suivant',
    'about_provider' => 'à propos du fournisseur',
    'service_total_time' => 'temps total du service',
    'check_status' => 'vérifier le statut',
    'Add-ons' => 'Suppléments',
    'about_handyman' => 'à propos du bricoleur',
    'rate_handyman' => 'évaluer le bricoleur',
    'price_detail' => 'Détail du prix',
    'subtotal' => 'Sous-total',
    'total' => 'Total',
    'total_extra_charges' => 'Total des frais supplémentaires',
    'coupon' => 'coupon',
    'tax' => 'impôt',
    'on_basis' => 'sur la base de 00:01 min',
    'extra_charges' => 'frais supplémentaires',
    'payment_detail' => 'détails de paiement',
    'id' => 'ID',
    'transaction_id' => 'ID de transaction',
    'request_invoice' => 'demander une facture',
    'your_review' => 'Votre avis',
    'your_rating' => 'Votre note',
    'review_for' => 'Avis pour',
    'forgot_title' => 'bienvenue dans notre bricoleur',
    'forgot_description' => 'Services de bricoleur qualifiés comme réparation, réparation et amélioration de votre espace avec expertise, rendant la vie plus facile, un projet à la fois.',
    'email' => 'Adresse e-mail',
    'overall_rating' => 'Note globale',
    'your' => 'Votre',
    'remember_me' => 'Se souvenir de moi',
    'handyman_provider_register' => 'Vous voulez vous inscrire en tant que fournisseur ou bricoleur?',
    'demo_accounts' => 'Comptes de démonstration',
    'admin' => 'Administrateur',
    'provider' => 'Fournisseur',
    'handyman' => 'Bricoleur',
    'user' => 'Utilisateur',
    'booking_history' => 'Historique des réservations',
    'why_choose_me'=>'Pourquoi me choisir?',
    'projects' => 'Projets',
    'satisfy_customers' => 'Satisfaire les clients',
    'project_completed' => 'Projets terminés',
    'provider_personal_info'=>'informations personnelles du fournisseur',
    'member_since'=>'Membre depuis',
    'languages' => 'Langues',
    'training' => 'Formation',
    'why_choose_me_title' => 'pourquoi me choisir comme votre prestataire de services de confiance',
    'user_name' => 'Nom d\'utilisateur',
    'minutes' => 'Minutes',
    'created_by' => 'Créé par',
    'about_service'=>'À propos des services',
    'about_provider' => 'À propos du fournisseur',
    'complet_project' => 'Projet terminé',
    'msg_complete_project' =>'Projet complet jusqu\'à présent',
    'order_detail' => 'Détail de la commande',
    'select_service_package' => 'sélectionner le service ou le forfait',
    'any_question' => 'Des questions?',
    'related_services' => 'services connexes',
    'read_more' => 'Lire la suite',
    'read_less' => 'Lire moins',
    'add_to_wishlist' => 'ajouter à la liste de souhaits',
    'share_this_service' => 'Partagez ce service',
    'copy_link' => 'Copier le lien',
    'business_inquries' => 'Demandes commerciales',
    'helpline_number' => 'Numéro d\'assistance',
    'facebook' => 'Facebook',
    'twitter' => 'Twitter',
    'instagram' => 'Instagram',
    'youtube' => 'YouTube',
    'advance_payment' => 'Paiement anticipé',
    'off' => 'Hors',
    'handyman_personal_info' => 'informations personnelles du bricoleur',
    'search' => 'Chercher',
    'select' => 'Sélectionner',
    'schedule_service' => 'Planifier le service',
    'remove' => 'Supprimer',
    'date_time' => 'Date et heure',
    'available_slots' => 'Créneaux disponibles',
    'slot_not_available' => 'Créneau non disponible',
    'quantity' => 'Quantité',
    'remove_coupon' => 'Supprimer le coupon',
    'pay_advance' => 'Payer à l\'avance',
    'save_booking' => 'Enregistrer la réservation',
    'edit_your_review' => 'Modifier votre avis',
    'delete' => 'Effacer',
    'all_categories' => 'Toutes les catégories',
    'all_providers' => 'Tous les fournisseurs',
    'all_price' => 'Tous les prix',
    'sort_by' => 'Trier par',
    'best_selling' => 'Meilleures ventes',
    'top_rated' => 'Les mieux notés',
    'newest' => 'Plus récent',
    'refresh' => 'Rafraîchir',
    'booking_detail' => 'détail de la réservation',
    'exp' => 'Exp',
    'applied' => 'Appliqué',
    'current_location' => 'emplacement actuel',
    'record_not_found' => 'Enregistrement non trouvé',
    'get_nearest_services' => 'Obtenez les services les plus proches',
    'continue_view_services' => 'Continuer à voir les services disponibles dans TOUS les domaines?',
    'discover_find_services' => 'Découvrez et trouvez des services disponibles dans votre région actuelle.',
    'off_location' => 'Hors emplacement',
    'post_job_service' => 'Post Job Service',
    'add_your_service' => 'Ajoutez votre service',
    'add_service_page_msg'=> 'ajouter ce service que vous ne trouvez pas dans nos services.',
    'Service_Category' => 'Catégorie de service',
    'select_category' => 'Sélectionnez une catégorie',
    'loading_categories' => 'Chargement des catégories',
    'service_name' => 'Nom du service',
    'Type' => 'Type',
    'advance_payment_option' => 'Option de paiement anticipé',
    'Proceed_To_Payment' => 'Procéder au paiement',
    'min' => 'Min',
    'services_booked' => 'services réservés',
    'subscribe_msg' => 'Merci de vous abonner',
    'pay_now' => 'Payer maintenant',
    'our_clients' => 'Nos clients',
    'hrs' => 'hrs',
    'reset' => 'Réinitialiser',
    'cancel_booking' => 'Annuler la réservation',
    'payment_option' => 'Option de paiement',
    'include_package' => 'Inclus dans ce forfait',
    'start' => 'Commencer',
    'hold' => 'Maintenir',
    'done' => 'Terminé',
    'resume' => 'Reprendre',
    'cancel' => 'Annuler',
    'reason' => 'Raison',
    'waiting_for_response' => 'En attente de réponse',
    'reason_modal_msg' => 'Êtes-vous sûr de vouloir maintenir ce service?',
    'cancel_modal_msg' => 'Veuillez donner la raison de l\'annulation de cette réservation',
    'job_request' => 'Demande d\'emploi',
    'near_by_location' => 'Emplacement à proximité',
    'handyman_category' => 'Catégorie de bricoleur',
    'popular_services' => 'Services populaires',
    'terms_conditions' => 'Termes et conditions',
    'privacy_policy' => 'Politique de confidentialité',
    'accept_all' => 'Tout accepter!',
    'reviews_for' => 'Avis pour',
    'min_read' => 'Min de lecture',
    'available_days' => 'Jours disponibles',
    'available_location' => 'Emplacement disponible',
    'all' => 'Tout',
    'view_more' => 'Voir plus',
    'location' => 'Emplacement',
    'slot_not_available' => 'Créneau non disponible',
    'get_current_location' => 'Obtenir l\'emplacement actuel',
    'data_deletion_request' => 'Deletation Request',
    'admin_login'=>'Admin Login',
];

==> handyman_updated_files11.10.0.zip: handyman_updated_files11.10.0/resources/lang/fr/landingpage.php <==
<?php

return [

    'home' => 'Accueil',
    'categories' => 'Catégories',
    'services' => 'Services',
    'blogs' => 'Blogs',
    'providers' => 'Fournisseurs',
    'bookings' => 'Réservations',
    'post_jobs' => 'Publier un emploi',
    'previous' => 'Précédent',
    'next' => 'Suivant',
    'post' => 'Post',
    'no_previous_post' => 'Aucun message précédent',
    'no_next_post' => 'Aucun message suivant',
    'about_provider' => 'à propos du fournisseur',
    'service_total_time' => 'temps total du service',
    'check_status' => 'vérifier le statut',
    'Add-ons' => 'Suppléments',
    'about_handyman' => 'à propos du bricoleur',
    'rate_handyman' => 'évaluer le bricoleur',
    'price_detail' => 'Détail du prix',
    'subtotal' => 'Sous-total',
    'total' => 'Total',
    'total_extra_charges' => 'Total des frais supplémentaires',
    'coupon' => 'coupon',
    'tax' => 'impôt',
    'on_basis' => 'sur la base de 00:01 min',
    'extra_charges' => 'frais supplémentaires',
    'payment_detail' => 'détails de paiement',
    'id' => 'ID',
    'transaction_id' => 'ID de transaction',
    'request_invoice' => 'demander une facture',
    'your_review' => 'Votre avis',
    'your_rating' => 'Votre note',
    'review_for' => 'Avis pour',
    'forgot_title' => 'bienvenue dans notre bricoleur',
    'forgot_description' => 'Services de bricoleur qualifiés comme réparation, réparation et amélioration de votre espace avec expertise, rendant la vie plus facile, un projet à la fois.',
    'email' => 'Adresse e-mail',
    'overall_rating' => 'Note globale',
    'your' => 'Votre',
    'remember_me' => 'Se souvenir de moi',
    'handyman_provider_register' => 'Vous voulez vous inscrire en tant que fournisseur ou bricoleur?',
    'demo_accounts' => 'Comptes de démonstration',
    'admin' => 'Administrateur',
    'provider' => 'Fournisseur',
    'handyman' => 'Bricoleur',
    'user' => 'Utilisateur',
    'booking_history' => 'Historique des réservations',
    'why_choose_me'=>'Pourquoi me choisir?',
    'projects' => 'Projets',
    'satisfy_customers' => 'Satisfaire les clients',
    'project_completed' => 'Réservations terminées',
    'provider_personal_info'=>'informations personnelles du fournisseur',
    'member_since'=>'Membre depuis',
    'languages' => 'Langues',
    'training' => 'Formation',
    'why_choose_me_title' => 'pourquoi me choisir comme votre prestataire de services de confiance',
    'user_name' => 'Nom d\'utilisateur',
    'minutes' => 'Minutes',
    'created_by' => 'Créé par',
    'about_service'=>'À propos des services',
    'about_provider' => 'À propos du fournisseur',
    'complet_project' => 'Projet terminé',
    'msg_complete_project' =>'Projet complet jusqu\'à présent',
    'order_detail' => 'Détail de la commande',
    'select_service_package' => 'sélectionner le service ou le forfait',
    'any_question' => 'Des questions?',
    'related_services' => 'services connexes',
    'read_more' => 'Lire la suite',
    'read_less' => 'Lire moins',
    'add_to_wishlist' => 'ajouter à la liste de souhaits',
    'share_this_service' => 'Partagez ce service',
    'copy_link' => 'Copier le lien',
    'business_inquries' => 'Demandes commerciales',
    'helpline_number' => 'Numéro d\'assistance',
    'facebook' => 'Facebook',
    'twitter' => 'Twitter',
    'instagram' => 'Instagram',
    'youtube' => 'YouTube',
    'advance_payment' => 'Paiement anticipé',
    'off' => 'Hors',
    'handyman_personal_info' => 'informations personnelles du bricoleur',
    'search' => 'Chercher',
    'select' => 'Sélectionner',
    'schedule_service' => 'Planifier le service',
    'remove' => 'Supprimer',
    'date_time' => 'Date et heure',
    'available_slots' => 'Créneaux disponibles',
    'slot_not_available' => 'Créneau non disponible',
    'quantity' => 'Quantité',
    'remove_coupon' => 'Supprimer le coupon',
    'pay_advance' => 'Payer à l\'avance',
    'save_booking' => 'Enregistrer la réservation',
    'edit_your_review' => 'Modifier votre avis',
    'delete' => 'Effacer',
    'all_categories' => 'Toutes les catégories',
    'all_providers' => 'Tous les fournisseurs',
    'all_price' => 'Tous les prix',
    'sort_by' => 'Trier par',
    'best_selling' => 'Meilleures ventes',
    'top_rated' => 'Les mieux notés',
    'newest' => 'Plus récent',
    'refresh' => 'Rafraîchir',
    'booking_detail' => 'détail de la réservation',
    'exp' => 'Exp',
    'applied' => 'Appliqué',
    'current_location' => 'emplacement actuel',
    'record_not_found' => 'Enregistrement non trouvé',
    'get_nearest_services' => 'Obtenez les services les plus proches',
    'continue_view_services' => 'Continuer à voir les services disponibles dans TOUS les domaines?',
    'discover_find_services' => 'Découvrez et trouvez des services disponibles dans votre région actuelle.',
    'off_location' => 'Hors emplacement',
    'post_job_service' => 'Post Job Service',
    'add_your_service' => 'Ajoutez votre service',
    'add_service_page_msg'=> 'ajouter ce service que vous ne trouvez pas dans nos services.',
    'Service_Category' => 'Catégorie de service',
    'select_category' => 'Sélectionnez une catégorie',
    'loading_categories' => 'Chargement des catégories',
    'service_name' => 'Nom du service',
    'Type' => 'Type',
    'advance_payment_option' => 'Option de paiement anticipé',
    'Proceed_To_Payment' => 'Procéder au paiement',
    'min' => 'Min',
    'services_booked' => 'services réservés',
    'subscribe_msg' => 'Merci de vous abonner',
    'pay_now' => 'Payer maintenant',
    'our_clients' => 'Nos clients',
    'hrs' => 'hrs',
    'reset' => 'Réinitialiser',
    'cancel_booking' => 'Annuler la réservation',
    'payment_option' => 'Option de paiement',
    'include_package' => 'Inclus dans ce forfait',
    'start' => 'Commencer',
    'hold' => 'Maintenir',
    'done' => 'Terminé',
    'resume' => 'Reprendre',
    'cancel' => 'Annuler',
    'reason' => 'Raison',
    'waiting_for_response' => 'En attente de réponse',
    'reason_modal_msg' => 'Êtes-vous sûr de vouloir maintenir ce service?',
    'cancel_modal_msg' => 'Veuillez donner la raison de l\'annulation de cette réservation',
    'job_request' => 'Demande d\'emploi',
    'near_by_location' => 'Emplacement à proximité',
    'handyman_category' => 'Catégorie de bricoleur',
    'popular_services' => 'Services populaires',
    'terms_conditions' => 'Termes et conditions',
    'privacy_policy' => 'Politique de confidentialité',
    'accept_all' => 'Tout accepter!',
    'reviews_for' => 'Avis pour',
    'min_read' => 'Min de lecture',
    'available_days' => 'Jours disponibles',
    'available_location' => 'Emplacement disponible',
    'all' => 'Tout',
    'view_more' => 'Voir plus',
    'location' => 'Emplacement',
    'slot_not_available' => 'Créneau non disponible',
    'get_current_location' => 'Obtenir l\'emplacement actuel',
    'data_deletion_request' => 'Deletation Request',
    'admin_login'=>'Admin Login',
];
